@@ -4,7 +4,7 @@ __PACKAGE__->load_components(qw/ RDBOHelpers Core /);
 __PACKAGE__->table('cd_track_join');
 __PACKAGE__->add_columns(qw/ trackid cdid /);
 __PACKAGE__->set_primary_key(qw/trackid cdid/);
-__PACKAGE__->belongs_to( 'cdid'    => 'MyDBIC::Schema::Cd' );
-__PACKAGE__->belongs_to( 'trackid' => 'MyDBIC::Schema::Track' );
+__PACKAGE__->belongs_to( 'cd'    => 'MyDBIC::Schema::Cd',    'cdid' );
+__PACKAGE__->belongs_to( 'track' => 'MyDBIC::Schema::Track', 'trackid' );
 
 1;
